==> zio-aws-amplifybackend_2.12-5.17.146.2-sources.jar: zio/aws/amplifybackend/model/DeleteBackendApiRequest.scala <==
package zio.aws.amplifybackend.model
import zio.aws.amplifybackend.model.primitives.__string
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DeleteBackendApiRequest(
    appId: __string,
    backendEnvironmentName: __string,
    resourceConfig: Option[
      zio.aws.amplifybackend.model.BackendAPIResourceConfig
    ] = None,
    resourceName: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.amplifybackend.model.DeleteBackendApiRequest = {
    import DeleteBackendApiRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.amplifybackend.model.DeleteBackendApiRequest
      .builder()
      .appId(appId: java.lang.String)
      .backendEnvironmentName(backendEnvironmentName: java.lang.String)
      .optionallyWith(resourceConfig.map(value => value.buildAwsValue()))(
        _.resourceConfig
      )
      .resourceName(resourceName: java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.amplifybackend.model.DeleteBackendApiRequest.ReadOnly =
    zio.aws.amplifybackend.model.DeleteBackendApiRequest.wrap(buildAwsValue())
}
object DeleteBackendApiRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.amplifybackend.model.DeleteBackendApiRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.amplifybackend.model.DeleteBackendApiRequest =
      zio.aws.amplifybackend.model.DeleteBackendApiRequest(
        appId,
        backendEnvironmentName,
        resourceConfig.map(value => value.asEditable),
        resourceName
      )
    def appId: __string
    def backendEnvironmentName: __string
    def resourceConfig
        : Option[zio.aws.amplifybackend.model.BackendAPIResourceConfig.ReadOnly]
    def resourceName: __string
    def getAppId: ZIO[Any, Nothing, __string] = ZIO.succeed(appId)
    def getBackendEnvironmentName: ZIO[Any, Nothing, __string] =
      ZIO.succeed(backendEnvironmentName)
    def getResourceConfig: ZIO[
      Any,
      AwsError,
      zio.aws.amplifybackend.model.BackendAPIResourceConfig.ReadOnly
    ] = AwsError.unwrapOptionField("resourceConfig", resourceConfig)
    def getResourceName: ZIO[Any, Nothing, __string] = ZIO.succeed(resourceName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.amplifybackend.model.DeleteBackendApiRequest
  ) extends zio.aws.amplifybackend.model.DeleteBackendApiRequest.ReadOnly {
    override val appId: __string = impl.appId(): __string
    override val backendEnvironmentName: __string =
      impl.backendEnvironmentName(): __string
    override val resourceConfig: Option[
      zio.aws.amplifybackend.model.BackendAPIResourceConfig.ReadOnly
    ] = scala
      .Option(impl.resourceConfig())
      .map(value =>
        zio.aws.amplifybackend.model.BackendAPIResourceConfig.wrap(value)
      )
    override val resourceName: __string = impl.resourceName(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.amplifybackend.model.DeleteBackendApiRequest
  ): zio.aws.amplifybackend.model.DeleteBackendApiRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-amplifybackend_2.13-5.17.128.1-sources.jar: zio/aws/amplifybackend/model/DeleteBackendApiRequest.scala <==
package zio.aws.amplifybackend.model
import zio.aws.amplifybackend.model.primitives.__string
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DeleteBackendApiRequest(
    appId: __string,
    backendEnvironmentName: __string,
    resourceConfig: Option[
      zio.aws.amplifybackend.model.BackendAPIResourceConfig
    ] = None,
    resourceName: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.amplifybackend.model.DeleteBackendApiRequest = {
    import DeleteBackendApiRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.amplifybackend.model.DeleteBackendApiRequest
      .builder()
      .appId(__string.unwrap(appId): java.lang.String)
      .backendEnvironmentName(
        __string.unwrap(backendEnvironmentName): java.lang.String
      )
      .optionallyWith(resourceConfig.map(value => value.buildAwsValue()))(
        _.resourceConfig
      )
      .resourceName(__string.unwrap(resourceName): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.amplifybackend.model.DeleteBackendApiRequest.ReadOnly =
    zio.aws.amplifybackend.model.DeleteBackendApiRequest.wrap(buildAwsValue())
}
object DeleteBackendApiRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.amplifybackend.model.DeleteBackendApiRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.amplifybackend.model.DeleteBackendApiRequest =
      zio.aws.amplifybackend.model.DeleteBackendApiRequest(
        appId,
        backendEnvironmentName,
        resourceConfig.map(value => value.asEditable),
        resourceName
      )
    def appId: __string
    def backendEnvironmentName: __string
    def resourceConfig
        : Option[zio.aws.amplifybackend.model.BackendAPIResourceConfig.ReadOnly]
    def resourceName: __string
    def getAppId: ZIO[Any, Nothing, __string] = ZIO.succeed(appId)
    def getBackendEnvironmentName: ZIO[Any, Nothing, __string] =
      ZIO.succeed(backendEnvironmentName)
    def getResourceConfig: ZIO[
      Any,
      AwsError,
      zio.aws.amplifybackend.model.BackendAPIResourceConfig.ReadOnly
    ] = AwsError.unwrapOptionField("resourceConfig", resourceConfig)
    def getResourceName: ZIO[Any, Nothing, __string] = ZIO.succeed(resourceName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.amplifybackend.model.DeleteBackendApiRequest
  ) extends zio.aws.amplifybackend.model.DeleteBackendApiRequest.ReadOnly {
    override val appId: __string =
      zio.aws.amplifybackend.model.primitives.__string(impl.appId())
    override val backendEnvironmentName: __string =
      zio.aws.amplifybackend.model.primitives
        .__string(impl.backendEnvironmentName())
    override val resourceConfig: Option[
      zio.aws.amplifybackend.model.BackendAPIResourceConfig.ReadOnly
    ] = scala
      .Option(impl.resourceConfig())
      .map(value =>
        zio.aws.amplifybackend.model.BackendAPIResourceConfig.wrap(value)
      )
    override val resourceName: __string =
      zio.aws.amplifybackend.model.primitives.__string(impl.resourceName())
  }
  def wrap(
      impl: software.amazon.awssdk.services.amplifybackend.model.DeleteBackendApiRequest
  ): zio.aws.amplifybackend.model.DeleteBackendApiRequest.ReadOnly =
    new Wrapper(impl)
}
